/**
 * commonly used DOM methods
 */

/**
 * @method focusElementInPanel
 * @description focuses element by selector and returns true if element is visible
 * @param {string} selector
 * @return {boolean}
 */
export function focusElementInPanel(selector) {
  const focusElement = document.querySelector(selector);
  focusElement.focus();

  // if element is hidden offsetHeight would be 0
  return focusElement.offsetHeight !== 0;
}

/**
 * @method ariaToggle
 * @description will toggle aria expanded attribute on all matching elements
 * @param {string} selector
 * @param {string} ariaLabel
 * @param {boolean} value
 * @return {void}
 */
export function ariaToggle(selector, ariaLabel, value) {
  const targetButton = Array.from(document.querySelectorAll(selector));

  targetButton.forEach((m) => {
    const ariaExpandedValue = typeof value !== "undefined" ? value : false;
    m.setAttribute("aria-expanded", ariaExpandedValue);

    const buttonText = m.querySelector(".c-control__button-text");
    buttonText.innerText = ariaLabel;
  });
}
